<?php
// $Id: ff1.newseason.inc,v 1.1.2.2 2011/02/10 23:38:02 ff1 Exp $

/**
 * @file
 * Allows admin to archive current teams and reset the fantasy formula 1 game.
 */

/**
 * Change existing team nodes into old team nodes, by moving all content to the
 * body field and changing the node type to 'old_team'.
 * Empty the following tables:
 *   ff1_results_raw
 *   ff1_results_formal
 *   ff1_component_scores
 *   ff1_component_sum_scores
 *   ff1_league_table
 *   ff1_teams
 * Update the last race variable
 * NOTE: You must create a node type 'old_team' on your site before running this.
 * NOTE: Ensure users cannot edit nodes of type 'old_team'.
 */
function ff1_new_season_batch_process(&$context) {
  if (!isset($context['sandbox']['progress'])) {
    $context['sandbox']['progress'] = 0;
    $context['sandbox']['current_node'] = 0;
    $context['sandbox']['max'] = db_result(db_query("SELECT COUNT(DISTINCT nid) FROM {node} WHERE type = 'ff1_team'"));
  }

  // For this example, we decide that we can safely process
  // 5 nodes at a time without a timeout.
  $limit = 5;

  // With each pass through the callback, retrieve the next group of nids.
  $result = db_query_range("SELECT nid FROM {node} WHERE nid > %d AND type = 'ff1_team' ORDER BY nid ASC", $context['sandbox']['current_node'], 0, $limit);
  while ($row = db_fetch_array($result)) {

    // Here we actually perform our processing on the current node.
    $node = node_load($row['nid'], NULL, TRUE);
    $node->body = '<div class="messages status">'. t('This is an archived team from %year.', array('%year' => date('Y')-1)) .'</div>'. theme($node->type, $node);
    $order = array("\r\n", "\n", "\r");
    $replace = "";
    $node->body = str_replace($order, $replace, $node->body);
    $node->format = 3; // Full HTML format
    // Change node type
    $node->type = 'old_team';
    $race = variable_get('ff1_last_race', 0); // Get the last race
    // Extract the final league information about this team
    $team_info = db_fetch_object(db_query("SELECT lt.rank, lt.team_score FROM {ff1_league_table} lt WHERE lt.team_nid = %d AND lt.race_nid = %d AND lt.table_type = 'points_so_far'", $node->nid, $race));
    $node->field_final_position[0]['value'] = $team_info->rank; // Final league position
    $node->field_team_points[0]['value'] = $team_info->team_score; // Final points
    $node->field_year[0]['value'] = date('Y')-1; // Season
    // Save new node
    $node = node_submit($node);
    node_save($node);
    content_insert($node);

    // Store some result for post-processing in the finished callback.
    $context['results'][] = check_plain($node->title);

    // Update our progress information.
    $context['sandbox']['progress']++;
    $context['sandbox']['current_node'] = $node->nid;
    $context['message'] = t('Now processing %current of %max', array('%current' => $context['sandbox']['progress'], '%max' => $context['sandbox']['max']));

    unset($node);
  }

  // Inform the batch engine that we are not finished,
  // and provide an estimation of the completion level we reached.
  if ($context['sandbox']['progress'] != $context['sandbox']['max']) {
    $context['finished'] = $context['sandbox']['progress'] / $context['sandbox']['max'];
  }
}

function ff1_new_season_batch_finished() {
  // Empty tables
  db_query("DELETE FROM {ff1_results_raw}");
  db_query("DELETE FROM {ff1_results_formal}");
  db_query("DELETE FROM {ff1_component_scores}");
  db_query("DELETE FROM {ff1_component_sum_scores}");
  db_query("DELETE FROM {ff1_league_table}");
  db_query("DELETE FROM {ff1_teams}");
  db_query("DELETE FROM {ff1_relationships} WHERE rel_type IN ('driver1', 'driver2', 'car', 'engine', 'league_team')");
  // Update the variable ff1_last_race
  variable_set('ff1_last_race', 0);
  // Set the mode to be pre-season
  variable_set('ff1_pre_season', 1);
  // Reset the tiebreaker value to 0
  variable_set('ff1_tiebreaker', 0);
  // Clear the cache so that new nodes become available.
  cache_clear_all();
  // Add a message to say that the site has been reset.
  drupal_set_message(t('Your site has been reset ready for a new season.'));
  watchdog('ff1', 'Your site has been reset ready for a new season.');
  // Go back to ff1 settings page
  //drupal_goto('admin/settings/ff1');
}
